#
# spec file for package ofono
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Sergey Kondakov <virtuousfox@gmail.com>.
# Copyright (c) 2014 Bernd Wachter <bwachter@lart.info>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ofono
Version:        1.23
Release:        17.1
Summary:        Mobile telephony application development framework
License:        GPL-2.0-only
Group:          Productivity/Telephony/Utilities
Url:            https://01.org/ofono
Source0:        https://www.kernel.org/pub/linux/network/ofono/%{name}-%{version}.tar.xz
Source1:        https://www.kernel.org/pub/linux/network/ofono/sha256sums.asc#/%{name}-%{version}.tar.xz.sig
Source2:        http://keyserver.ubuntu.com:11371/pks/lookup?op=get&search=0x589DA6B1#/%{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bluez) >= 4.85
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libudev) >= 145
BuildRequires:  pkgconfig(mobile-broadband-provider-info)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
%systemd_requires

%description
oFono provides a mobile telephony (GSM/UMTS) application development
framework. It includes a high-level D-Bus API for use by telephony
applications, and a low-level plug-in API for integration with other
stacks, cellular modems, and storage back ends. The plug-in API
functionality is modeled on public standards, in particular 3GPP TS
27.007 "AT command set for User Equipment (UE)".

%package devel
Summary:        Development files for ofono, a mobile telephony framework
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
oFono provides a mobile telephony (GSM/UMTS) application development
framework. It includes a high-level D-Bus API for use by telephony
applications, and a low-level plug-in API.

This subpackage contains the header files for developing
applications that want to make use of ofono.

%package tests
Summary:        Test Scripts for oFono
Group:          Productivity/Telephony/Utilities
Requires:       %{name} = %{version}
Provides:       ofono-test >= 1.0
Obsoletes:      ofono-test < 1.0

%description tests
Scripts for testing oFono and its functionality.

%prep
%setup -q

%build
%configure \
  --disable-static \
  --enable-pie \
  --enable-threads \
  --enable-test \
  --with-systemdunitdir="%{_libexecdir}/systemd/system"
make %{?_smp_mflags} V=1

%install
%make_install

ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

mkdir -p %{buildroot}%{_libexecdir}/systemd/system/network.target.wants
ln -s ../ofono.service %{buildroot}%{_libexecdir}/systemd/system/network.target.wants/ofono.service

%pre
%service_add_pre ofono.service

%post
%service_add_post ofono.service

%preun
%service_del_preun ofono.service

%postun
%service_del_postun ofono.service

%files
%doc ChangeLog README COPYING
%{_sbindir}/ofonod
%{_sbindir}/rc%{name}
%{_mandir}/man8/ofonod.8%{?ext_man}
%{_unitdir}/ofono.service
%{_libexecdir}/systemd/system/network.target.wants/ofono.service
%dir %{_libexecdir}/systemd/system/network.target.wants
%config %{_sysconfdir}/ofono/
%config %{_sysconfdir}/dbus-1/system.d/ofono.conf

%files devel
%doc ChangeLog README COPYING
%dir %{_includedir}/ofono/
%{_includedir}/ofono/*
%{_libdir}/pkgconfig/ofono.pc

%files tests
%doc ChangeLog README COPYING
%{_libdir}/%{name}/test/*
%dir %{_libdir}/%{name}/test
%dir %{_libdir}/%{name}

%changelog
* Sun Mar 11 2018 mardnh@gmx.de
- Update to version 1.23:
  * Fix issue with handling SIM AID sessions.
  * Add support for QMI LTE bearer handling.
  * Add support for memory location dialing.
* Sat Jan 27 2018 mardnh@gmx.de
- Update to version 1.22:
  * Fix issue with GPIO handling and Nokia modems.
  * Fix issue with SIM state callback and AT modems.
  * Fix issue with data mode and DCD for U-Blox modems.
  * Fix issue with SMS receive on QMI based Quectel EC21.
  * Fix issue with HFP support and last call dialed request.
  * Fix issue with PIM retires handling and Gemalto modems.
  * Fix issue with atom registration and SIM state handling.
  * Add support for handling SIM card AID session management.
  * Add support for handling GSM/UMTS and IMS authentication.
  * Add support for IP Multimedia Subsystem (IMS) atom.
  * Add support for MBIM based modems.
- Cosmetic cleanup of the last changelog
- Fix RPM URL
- Verify source signature
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 1.21:
  * Fix issue with USSD notification received handling.
  * Fix issue with crashing SIM filesystem notifications.
  * Fix issue with LTE bearer reporting and Huawei modems.
  * Fix issue with invalid memory access and QMI.
  * Add support for QMI SIM writing functionality.
  * Add support for RAT selection for QMI modems.
  * Add support for network monitor agent interface.
  * Add support for Cinterion Hardware Monitor interface.
  * Add support for LTE atom driver for Huawei modems.
  * Add support for LTE atom driver for AT modems.
  * Add support for Intel xmm7xxx series modems.
* Mon Oct  2 2017 jengelh@inai.de
- Update description from webpage.
* Mon Oct  2 2017 mpluskal@suse.com
- Update to version 1.20:
  * Fix issue with context removal before activation.
  * Fix issue with update during GPRS context activation.
  * Fix issue with receiving UTF-16 encoded messages.
  * Fix issue with invalid access in CBS decoding.
  * Fix issue with signal strength on QMI modems.
  * Fix issue with PIN handling with QMI modems.
  * Fix issue with QMI notification message handling.
  * Fix issue with facility lock query on SIM removal.
  * Fix issue with parsing +CLCC and +CCWA fields.
  * Add support for obtaining IMSI via EF reading.
  * Add support for additional netmon info types.
  * Add support for provisioning via configuration files.
  * Add support for Gemalto P-family series of modems.
  * Add support for Telit HE910 and UE910 variants.
  * Add support for Intel SoFIA SIM Toolkit interfaces.
  * Add support for Intel SoFIA LTE features.
  * Add support for U-Blox TOBY-L2 LTE feature.
  * Add support for dedicated LTE atom.
* Thu Nov 24 2016 mpluskal@suse.com
- Update to version 1.19:
  * Fix issue with DHCP parsing and Huawei modems.
  * Fix issue with detecting Huawei E3372 modem.
  * Fix issue with handling serving cell info.
  * Fix issue with handling SIM SC facility lock.
  * Fix issue with Android RIL PIN retry logic.
  * Fix issue with Android RIL and RAT handling.
  * Add support for Android RIL cell broadcast.
  * Add support for SoFIA 3GR thermal management.
* Sun Jun 12 2016 mpluskal@suse.com
- Update to version 1.18:
  * Fix issue with cell broadcast and use-after-fee.
  * Fix issue with repeated held call indicator.
  * Fix issue with +CCWA and connection setup.
  * Fix issue with empty operator scan results.
  * Fix issue with persistent RAT mode handling.
  * Fix issue with multiparty call introspection.
  * Fix issue with GRPS context introspection.
  * Fix issue with stale context deactivation.
  * Add support for automatic context activation.
  * Add support for SIM service provider names.
  * Add support for handling allowed APN lists.
  * Add support for network monitoring interface.
  * Add support for U-Blox TOBY-L2 modem series.
  * Add support for Sierra MC73xx QMI modems.
  * Add support for SoFIA 3GR modem series.
  * Add support for upower battery monitoring.
  * Add support for gateway audio card types.
  * Add support for Handsfree audio driver.
  * Add support for Android RIL integration.
- Use correct package groups
- Build as pie with enabled thread support
* Fri Nov 13 2015 mpluskal@suse.com
- Update to 1.17:
  * Fix issue with alphanumeric TP-OA handling.
  * Fix issue with push notification origin port.
  * Fix issue with reading of EF_MWIS records.
  * Fix issue with handling AT+CPINR results.
  * Fix issue with SIM state polling for Sierra modems.
  * Fix issue with HFP handling and AT command prefixes.
  * Fix issue with HFP and extra CCWA event handling.
  * Fix issue with HFP call state and +CHUP errors.
- Update dependencies
* Mon Feb 16 2015 mpluskal@suse.com
- Update to 1.16:
  * Fix issue with PIN retry handling.
  * Fix issue with HFP and multiple calls.
  * Add support for Distracted Driving Reduction.
  * Add support for available technologies property.
  * Add support for Telit location reporting driver.
  * Add support for u-blox SARA-U270 modems.
  * Add support for Quectel UC15 modems.
- Clean up spec-file with spec-cleaner
- Clean unnecessary dependencies
- Enable unit tests when building
* Thu Jul 24 2014 virtuousfox@gmail.com
- Update to 1.15
* Wed Jan 16 2013 Petri M. Gerdt <petri.gerdt@jollamobile.com> - 1.11
- add patch 0001-Experimental-network-time-plugin.patch which adds
  an API for accessing cellular network time.
* Mon Dec 10 2012 Lorn Potter <lorn.potter@jollamobile.com> - 1.11
- upgrade ofono to 1.11
* Fri Aug 24 2012 Jarko Poutiainen <jarko.poutiainen@tieto.com> - 1.10
- upgrade ofono to 1.10
- remove n950 patches
- add patch to disable cbs from n900 plugin
- add patch to fix answering for N9 modem
* Thu Aug 23 2012 Carsten Munk <carsten.munk@jollamobile.com> - 1.8
- Add isimodem-fix-incoming-calls.patch to fix incoming calls on isimodem
* Wed Jul 11 2012 Marko Saukko <marko.saukko@jollamobile.com> - 1.8
- Fixes MER#285: upgrade ofono to recent version
- Fixes MER#422: ofono-test package requires python dbus bindings.
- Rename -test packages to -tests
* Wed Sep 21 2011 Sami Sirkia <sami.sirkia@cybercom.com> - 0.52
- Include patches for N950
* Fri Sep 16 2011 Jouni Peltonen <jouni.peltonen@cybercom.com> - 0.52
- Patch BMC22161-isi-call-id.patch added to correct isi modem answering
  BMC #22161.
* Tue Jul 19 2011 Yu <yu.a.wang@intel.com> - 0.52
- upgrade to 0.52
* Wed Jul 13 2011 Yu <yu.a.wang@intel.com> - 0.51
- upgrade to 0.51
* Thu Jun 23 2011 Yu <yu.a.wang@intel.com> - 0.50
- upgrade to 0.50
* Thu Jun 23 2011 Yu <yu.a.wang@intel.com> - 0.49
- Remove requirement for package usb-modeswitch and use-modeswitch-date due to this is not the right way to fix BMC#19097
- Release engineer already added these two packages to package-groups
* Wed Jun 15 2011 Yu <yu.a.wang@intel.com> - 0.49
- Add requirement for package usb-modeswitch and usb-modeswitch-data fix BMC#19097
* Wed Jun  8 2011 Yu <yu.a.wang@intel.com> - 0.49
- upgrade to 0.49
* Wed May 25 2011 Chris Ferron <chris.e.ferron@linux.intel.com> - 0.48
- Updated spec file to change systemctl as a requires to the package systemd
- for each scriplet section. Also added a Requires systemd as systemd is configured
- as a build option for this package exposing systemd features.
* Tue May  3 2011 Chris Ferron <chris.e.ferron@linux.intel.com> - 0.48
- FEA#16109 - [FEA] Implement SystemD as MeeGo init provide
- Updated the ofono package to be usable by systemd as needed
  to implement systemd as the init provider of MeeGo. For this
  a systemd ofono.service file was added and installed. This will
  allow systemd to start stop and track the service.
* Fri Apr 29 2011 Junfeng Dong <junfeng.dong@intel.com> - 0.48  
- Fix the error caused by updating libtool.
* Tue Apr 26 2011 Yu <yu.a.wang@intel.com> - 0.48
- upgrade to 0.48 for BMC #14213
- Fix issue with crash due to not stopped PPP timers.
- Fix issue with offline mode handling and Huawei modem.
- Fix issue with missing check for Huawei modem device open.
- Fix issue with USSD and use of non-cloned GAtChat object.
* Sun Apr 17 2011 Yu <yu.a.wang@intel.com> - 0.47
- upgrade to 0.47 for BMC #14213
- Fix issue with entering offline mode prematurely.
- Add support for CPHS CSP network registration handling.
* Wed Apr 13 2011 Yu <yu.a.wang@intel.com> - 0.46
- upgrade to 0.46
- Fix issue with operator name reading and older ISI modems.
- Fix issue with networking registration and older ISI modems.
- Fix issue with missing handling of PIN/SIM states and ISI modems.
- Fix issue with voice call state reporting and ISI modems.
- Fix issue with STK handling of environment variables.
- Fix issue with STK and empty URL for launch browser.
- Fix issue with voice call pause character validation.
- Fix issue with buffer length and long phone numbers.
- Fix issue with SMS sending retries and network timeout.
- Fix issue with missing SMS submit canceled history status.
- Add support for cancellation of SMS submission.
- Add support for handling SIM Toolkit display action commands.
- Add support for handling call forwarding and SIM refresh.
- Add support for handling EFimg and EFiidf changes.
- Add support for handling EFmsisdn and EFsdn changes.
- Add support for handling emergency calls without SIM.
- Add support for handling emergency calls without PIN.
- Add support for handling emergency number updates.
- Add support for assisted satellite navigation interface.
- Add support for IPv6 contexts and ISI modems.
- Add support for dual-stack GPRS contexts.
- Add limited support for CDMA connection manager interface.
* Mon Mar 28 2011 Yu <yu.a.wang@intel.com> - 0.45
- upgrade to 0.45
- remove three already integrated patches
- Fix issue with SIM Toolkit null data object.
- Fix issue with SIM filesystem and modem release.
- Fix issue with disconnect handling and Huawei modems.
- Add support for improved SSN and voicecall handling.
- Add support for SIM Toolkit Refresh handled by the modem.
- Add support for multiple AT channels and STE modems.
- Add support for ISI drivers and wgmodem2.5 handling.
- Add support for optimized ringbuffer operations.
- Add support for optimized PPP buffer management.
* Fri Feb 18 2011 Martin Xu <martin.xu@intel.com> - 0.41
- Add patches:
-   0001_fix_huawei_em770w.patch
-   0002_fix_huawei_em770w.patch
-   0003_fix_huawei_em770w.patch
- to fix BMC #6944 #10018 #9797 #9201
* Wed Feb  9 2011 Martin Xu <martin.xu@intel.com> - 0.41
- upgrade to 0.41 for BMC #12692
- Fix issue with SIM callback handling.
- Fix issue with XTMS handling and IFX modem.
- Add support for alphabets and SMS encoding.
- Add support for generic PIN retries handling.
- Add support for PIN retries and MBM modem.
- Add support for radio settings and MBM modem.
- Add support for cell broadcast and STE modem.
- Add support for handling ECAV status Released.
* Thu Jan 27 2011 Jouni Peltonen <jouni.peltonen@cybercom.com> - 0.39
- Fixes BMC#12559.
- 0001-isimodem-Fix-race-condition-in-SIM-probe.patch upstream commit: 9306837053cd6ce35e0fe02f03c3cd0eba443f6c.
- 0002-n900-Fix-online.patch upstream commit: f6f0f4d12116cbf8787928146b3b97df21acb739
* Fri Jan 21 2011 Martin Xu <martin.xu@intel.com> - 0.39
- upgrade to 0.39 for BMC #12692
-  Fix issue with not handling empty EFecc properly.
-  Fix issue with string length and DTMF handling.
-  Fix issue with missing info for terminal busy result.
-  Fix issue with signal strength handling and IFX modem.
-  Fix handling of SIM Toolkit enabling and IFX modem.
-  Add support for packet switched bearer notifications.
-  Add support for handling called line identification.
-  Add support for PIN retry counter interface.
-  Add support for ST-Ericsson modem init daemon.
-  Add support for Cinterion TC65 modem.
-  Add support for simple ISI client interface.
* Fri Jan  7 2011 Martin Xu <martin.xu@intel.com> - 0.38
- upgrade to 0.38 for BMC #12501
- Change CalledLine* to ConnectedLine* properties.
- Fix issue with calling presentation property.
- Fix issue with network time and ISI modems.
- Fix issue with timezone reporting and HSO modems.
- Fix issue with SIM ready status and HSO modems.
- Fix issue with hidden caller ID and STE modems.
- Fix issue with handling of STK Setup Menu.
- Fix issue with missing STK text and icon checks.
- Fix issue with missing signal strength query.
* Wed Dec  8 2010 Martin Xu <martin.xu@intel.com> - 0.36
- upgrade to 0.36
-  Fix issue with CLIR Invocation and Suppression.
-  Fix issue with power/online transition with ZTE devices.
-  Fix segmentation fault when removing Nokia Datacard.
-  Add support for Nokia CS-17 dongles.
-  Add support for Ericsson F5521gw devices.
-  Add support for CAIF network interface management.
-  Add support for COLR in generic AT modem driver.
-  Add support for SMS Point-to-Point download to UICC.
-  Add support for checking specific service availability.
-  Add support for handling null text field for STK.
* Mon Nov 15 2010 Martin Xu <martin.xu@intel.com> - 0.35
- upgrade to 0.35
* Wed Nov  3 2010 Martin Xu <martin.xu@intel.com> - 0.34
- upgrade to 0.34
* Tue Oct 26 2010 Martin Xu <martin.xu@intel.com> - 0.33
- upgrade to 0.33 to fix IFX-MAL bugs
* Wed Oct 13 2010 Anas Nashif <nashif@linux.intel.com> - 0.31
- Remove requirement on ofono-config
- Remove unused and obsolete patches
* Mon Oct 11 2010 Martin Xu <martin.xu@intel.com> - 0.31
- upgrade to 0.31
- Remove the N900 package patches, waiting for them in upstream
* Tue Sep 21 2010 Marko Saukko <marko.saukko@cybercom.com> - 0.26
- Updated N900 patch
- Added modem.conf back as phonet is autodetected with the new patches.
- This is the final piece of implementing FEA#4134, FEA#4135, FEA#4136
  (Dialer - Make call, end call, receive call) on ARM/N900.
- Fixes BMC#5662 (Nokia N900 modem does not turn on in Ofono)
* Fri Sep  3 2010 Carsten Valdemar Munk <carsten@maemo.org> - 0.26
- Include N900 patch
- Seperate modem.conf out into seperate packages providing ofono-config. Reasoning is because there might be other
  devices with phonet0, not all n900modem.
* Thu Aug 26 2010 Martin Xu <martin.xu@intel.com> - 0.26
- upgrade to 0.26
* Mon Jul 19 2010 Martin Xu <martin.xu@intel.com> - 0.25
- upgrade to 0.25
* Wed Jul 14 2010 Martin Xu <martin.xu@intel.com> - 0.24
- upgrade to 0.24
* Tue Jun 22 2010 Martin Xu <martin.xu@intel.com> - 0.23
- Upgrade to 0.23
* Fri May  7 2010 Prajwal Mohan <prajwal.karur.mohan@intel.com> - 0.20  
- Enabling phonesim for handset images
* Thu Mar 25 2010 Martin Xu <martin.xu@intel.com> - 0.20
- Upgrade to 0.20
* Tue Feb 23 2010 Martin Xu <martin.xu@intel.com> - 0.18
- upgrade to 0.18
- remove 0001-add-netmask-to-hso-gprs-context-driver.patch
* Mon Feb 22 2010 Anas Nashif <anas.nashif@intel.com> - 0.15
- Use spectacle
- Update Group
* Tue Jan  5 2010 Martin Xu <martin.xu@intel.com> - 0.15
- upgrade to 0.15
- add patch 0001-add-netmask-to-hso-gprs-context-driver.patch
* Mon Dec 14 2009 Martin Xu <martin.xu@intel.com> - 0.14
- upgrade to 0.14
* Mon Dec  7 2009 Martin Xu <martin.xu@intel.com> - 0.13
- remove 0001-Allow-builds-to-install-the-test-scripts-for-debuggi.patch
- remove use_AT_CFUN_to_query_powered_state.patch
- patches has been merged in upstream
* Mon Dec  7 2009 Martin Xu <martin.xu@intel.com> - 0.13
- upgrade to 0.13
* Thu Dec  3 2009 Martin Xu <martin.xu@intel.com> - 0.12
- upgrade to 0.12
- clean up spec file
- add test subpackage
* Wed Nov 25 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.11
  Update to version 0.11
* Wed Oct 21 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Additional helper scripts added
* Mon Oct 19 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Fix install perms on .desktop file
* Mon Oct 19 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Fixed .ini file and actually added the .desktop file this time
* Mon Oct 19 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Add .desktop file back in
* Wed Oct 14 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Fix build
* Wed Oct 14 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Fix build
* Wed Oct 14 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Remove service autostart and allow to run as default user
* Tue Oct  6 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Fix hardcoded modem path in ofono-modem-power script
* Tue Oct  6 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.7
  Update to version 0.7
* Fri Sep 11 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Obsolete now defunct ofono-extras package
* Thu Sep 10 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Updated ofono-devel.files with man files and header glob
* Thu Sep 10 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Fixed bad ref to modem.conf in ofono.files
* Thu Sep 10 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Created missing bin dir
* Thu Sep 10 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Created missing autostart and dbus dirs
* Thu Sep 10 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Fixed bad sysconfdir reference
* Thu Sep 10 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.4
  Update to version 0.4
  Added moblin specific configurations and patches
* Fri Jul 31 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.2
- Add new headers to ofono-devel.files list
* Fri Jul 31 2009 Shane Bryan <shane.bryan@linux.intel.com> - 0.2
- Update to tip of tree (0.2+)
* Wed Jun 24 2009 Shane Bryan <shane.bryan@linux.intel.com> 0.0
- Tip of tree update (127b56baccc8830eb1), plus my patches
* Tue Jun 23 2009 Shane Bryan <shane.bryan@linux.intel.com> 0.0
- Add new history.h to installed devel file list
* Tue Jun 23 2009 Shane Bryan <shane.bryan@linux.intel.com> 0.0
- Pulling in latest from tip or tree
* Thu May 21 2009 Shane Bryan <shane.bryan@linux.intel.com> 0.0
- Initial import into Moblin, based on upstream ofono.org git,
  commit c427cdfdfacbec9b0221e157797e6c9d33113e91
